@@ -6,7 +6,7 @@ import (
 	"os"
 	"testing"
 
-	"github.com/cli/go-gh/pkg/config"
+	"github.com/cli/go-gh/v2/pkg/config"
 	"github.com/stretchr/testify/assert"
 )
 
@@ -89,7 +89,7 @@ func TestResolveLauncher(t *testing.T) {
 			}
 			if tt.config != nil {
 				old := config.Read
-				config.Read = func() (*config.Config, error) {
+				config.Read = func(_ *config.Config) (*config.Config, error) {
 					return tt.config, nil
 				}
 				defer func() { config.Read = old }()
