@@ -7,7 +7,6 @@ package tableprinter
 import (
 	"fmt"
 	"io"
-	"strings"
 
 	"github.com/cli/go-gh/v2/pkg/text"
 )
@@ -15,6 +14,7 @@ import (
 type fieldOption func(*tableField)
 
 type TablePrinter interface {
+	AddHeader([]string, ...fieldOption)
 	AddField(string, ...fieldOption)
 	EndRow()
 	Render() error
@@ -22,15 +22,27 @@ type TablePrinter interface {
 
 // WithTruncate overrides the truncation function for the field. The function should transform a string
 // argument into a string that fits within the given display width. The default behavior is to truncate the
-// value by adding "..." in the end. Pass nil to disable truncation for this value.
+// value by adding "..." in the end. The truncation function will be called before padding and coloring.
+// Pass nil to disable truncation for this value.
 func WithTruncate(fn func(int, string) string) fieldOption {
 	return func(f *tableField) {
 		f.truncateFunc = fn
 	}
 }
 
+// WithPadding overrides the padding function for the field. The function should transform a string argument
+// into a string that is padded to fit within the given display width. The default behavior is to pad fields
+// with spaces except for the last field. The padding function will be called after truncation and before coloring.
+// Pass nil to disable padding for this value.
+func WithPadding(fn func(int, string) string) fieldOption {
+	return func(f *tableField) {
+		f.paddingFunc = fn
+	}
+}
+
 // WithColor sets the color function for the field. The function should transform a string value by wrapping
 // it in ANSI escape codes. The color function will not be used if the table was initialized in non-terminal mode.
+// The color function will be called before truncation and padding.
 func WithColor(fn func(string) string) fieldOption {
 	return func(f *tableField) {
 		f.colorFunc = fn
@@ -47,6 +59,7 @@ func New(w io.Writer, isTTY bool, maxWidth int) TablePrinter {
 			maxWidth: maxWidth,
 		}
 	}
+
 	return &tsvTablePrinter{
 		out: w,
 	}
@@ -55,13 +68,27 @@ func New(w io.Writer, isTTY bool, maxWidth int) TablePrinter {
 type tableField struct {
 	text         string
 	truncateFunc func(int, string) string
+	paddingFunc  func(int, string) string
 	colorFunc    func(string) string
 }
 
 type ttyTablePrinter struct {
-	out      io.Writer
-	maxWidth int
-	rows     [][]tableField
+	out        io.Writer
+	maxWidth   int
+	hasHeaders bool
+	rows       [][]tableField
+}
+
+func (t *ttyTablePrinter) AddHeader(columns []string, opts ...fieldOption) {
+	if t.hasHeaders {
+		return
+	}
+
+	t.hasHeaders = true
+	for _, column := range columns {
+		t.AddField(column, opts...)
+	}
+	t.EndRow()
 }
 
 func (t *ttyTablePrinter) AddField(s string, opts ...fieldOption) {
@@ -104,11 +131,10 @@ func (t *ttyTablePrinter) Render() error {
 			if field.truncateFunc != nil {
 				truncVal = field.truncateFunc(colWidths[col], field.text)
 			}
-			if col < numCols-1 {
-				// pad value with spaces on the right
-				if padWidth := colWidths[col] - text.DisplayWidth(field.text); padWidth > 0 {
-					truncVal += strings.Repeat(" ", padWidth)
-				}
+			if field.paddingFunc != nil {
+				truncVal = field.paddingFunc(colWidths[col], truncVal)
+			} else if col < numCols-1 {
+				truncVal = text.PadRight(colWidths[col], truncVal)
 			}
 			if field.colorFunc != nil {
 				truncVal = field.colorFunc(truncVal)
@@ -213,7 +239,9 @@ type tsvTablePrinter struct {
 	currentCol int
 }
 
-func (t *tsvTablePrinter) AddField(text string, opts ...fieldOption) {
+func (t *tsvTablePrinter) AddHeader(_ []string, _ ...fieldOption) {}
+
+func (t *tsvTablePrinter) AddField(text string, _ ...fieldOption) {
 	if t.currentCol > 0 {
 		fmt.Fprint(t.out, "\t")
 	}
